@@ -11,6 +11,7 @@ __all__ = (
     "SubscriptionDidNotSucceed",
     "PersistedQueryNotFound",
     "SubscribeError",
+    "InvalidResponse",
 )
 
 
@@ -52,3 +53,7 @@ class PersistedQueryNotFound(PnWKitException):
 
 class SubscribeError(PnWKitException):
     ...
+
+
+class InvalidResponse(PnWKitException):
+    ...
